==> Subsurface-4.8.6.tgz: Subsurface-4.8.6/translations/subsurface_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en_US" version="2.1">
<context>
    <name>AddDivesToTrip</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="700"/>
        <source>add %n dives to trip</source>
        <translation><numerusform>add %n dive to trip</numerusform><numerusform>add %n dives to trip</numerusform></translation>
    </message>
</context>
<context>
    <name>CheckCloudConnection</name>
    <message numerus="yes">
        <location filename="../core/checkcloudconnection.cpp" line="58"/>
        <source>Waiting for cloud connetion (%n second(s) passed)</source>
        <translation><numerusform>Waiting for cloud connetion (%n second passed)</numerusform><numerusform>Waiting for cloud connetion (%n seconds passed)</numerusform></translation>
    </message>
</context>
<context>
    <name>Command::DeleteDive</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="558"/>
        <source>delete %n dive(s)</source>
        <translation><numerusform>delete %n dive</numerusform><numerusform>delete %n dives</numerusform></translation>
    </message>
</context>
<context>
    <name>DiveObjectHelper</name>
    <message numerus="yes">
        <location filename="../core/subsurface-qt/DiveObjectHelper.cpp" line="336"/>
        <source>(%n dive(s))</source>
        <translation><numerusform>(%n dive)</numerusform><numerusform>(%n dives)</numerusform></translation>
    </message>
</context>
<context>
    <name>LocationFilterDelegate</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/modeldelegates.cpp" line="504"/>
        <source>, %n dive(s) here)</source>
        <translation><numerusform>, %n dive here)</numerusform><numerusform>, %n dives here)</numerusform></translation>
    </message>
</context>
<context>
    <name>RemoveDivesFromTrip</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="680"/>
        <source>remove %n dive(s) from trip</source>
        <translation><numerusform>remove %n dive from trip</numerusform><numerusform>remove %n dives from trip</numerusform></translation>
    </message>
</context>
<context>
    <name>RenumberDives</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="640"/>
        <source>renumber %n dive(s)</source>
        <translation><numerusform>renumber %n dive</numerusform><numerusform>renumber %n dives</numerusform></translation>
    </message>
</context>
<context>
    <name>ShiftTime</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="597"/>
        <source>shift time of %n dives</source>
        <translation><numerusform>shift time of %n dive</numerusform><numerusform>shift time of %n dives</numerusform></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <location filename="../core/qthelper.cpp" line="997"/>
        <source>(%n dive(s))</source>
        <translation><numerusform>(%n dive)</numerusform><numerusform>(%n dives)</numerusform></translation>
    </message>
</context>
</TS>

==> Subsurface-4.9.3.tgz: Subsurface-4.9.3/translations/subsurface_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en_US" version="2.1">
<context>
    <name>AddDivesToTrip</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="700"/>
        <source>add %n dives to trip</source>
        <translation><numerusform>add %n dive to trip</numerusform><numerusform>add %n dives to trip</numerusform></translation>
    </message>
</context>
<context>
    <name>CheckCloudConnection</name>
    <message numerus="yes">
        <location filename="../core/checkcloudconnection.cpp" line="58"/>
        <source>Waiting for cloud connetion (%n second(s) passed)</source>
        <translation><numerusform>Waiting for cloud connetion (%n second passed)</numerusform><numerusform>Waiting for cloud connetion (%n seconds passed)</numerusform></translation>
    </message>
</context>
<context>
    <name>Command</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_edit.cpp" line="77"/>
        <source>Edit %1 (%n dive(s))</source>
        <extracomment>remove the part in parentheses for %n = 1</extracomment>
        <translation><numerusform>Edit %1 (%n dive)</numerusform><numerusform>Edit %1 (%n dives)</numerusform></translation>
    </message>
</context>
<context>
    <name>Command::DeleteDive</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="558"/>
        <source>delete %n dive(s)</source>
        <translation><numerusform>delete %n dive</numerusform><numerusform>delete %n dives</numerusform></translation>
    </message>
</context>
<context>
    <name>Command::DeleteDiveSites</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divesite.cpp" line="141"/>
        <source>delete %n dive site(s)</source>
        <translation><numerusform>delete %n dive site</numerusform><numerusform>delete %n dive sites</numerusform></translation>
    </message>
</context>
<context>
    <name>Command::ImportDives</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="452"/>
        <source>import %n dive(s) from %1</source>
        <translation><numerusform>import %n dive from %1</numerusform><numerusform>import %n dives from %1</numerusform></translation>
    </message>
</context>
<context>
    <name>DiveObjectHelper</name>
    <message numerus="yes">
        <location filename="../core/subsurface-qt/DiveObjectHelper.cpp" line="336"/>
        <source>(%n dive(s))</source>
        <translation><numerusform>(%n dive)</numerusform><numerusform>(%n dives)</numerusform></translation>
    </message>
</context>
<context>
    <name>DiveSiteSortedModel</name>
    <message numerus="yes">
        <location filename="../qt-models/divelocationmodel.cpp" line="272"/>
        <source>This dive site has %n dive(s). Do you really want to delete it?
</source>
        <translation><numerusform>This dive site has %n dive. Do you really want to delete it?
</numerusform><numerusform>This dive site has %n dives. Do you really want to delete it?
</numerusform></translation>
    </message>
</context>
<context>
    <name>EditTagsBase</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_edit.cpp" line="513"/>
        <source>Edit %1 (%n dive(s))</source>
        <extracomment>remove the part in parentheses for %n = 1</extracomment>
        <translation><numerusform>Edit %1 (%n dive)</numerusform><numerusform>Edit %1 (%n dives)</numerusform></translation>
    </message>
</context>
<context>
    <name>LocationFilterDelegate</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/modeldelegates.cpp" line="504"/>
        <source>, %n dive(s) here)</source>
        <translation><numerusform>, %n dive here)</numerusform><numerusform>, %n dives here)</numerusform></translation>
    </message>
</context>
<context>
    <name>PasteDives</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_edit.cpp" line="733"/>
        <source>Paste onto %n dive(s)</source>
        <translation><numerusform>Paste onto %n dive</numerusform><numerusform>Paste onto %n dives</numerusform></translation>
    </message>
</context>
<context>
    <name>RemoveDivesFromTrip</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="680"/>
        <source>remove %n dive(s) from trip</source>
        <translation><numerusform>remove %n dive from trip</numerusform><numerusform>remove %n dives from trip</numerusform></translation>
    </message>
</context>
<context>
    <name>RenumberDives</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="640"/>
        <source>renumber %n dive(s)</source>
        <translation><numerusform>renumber %n dive</numerusform><numerusform>renumber %n dives</numerusform></translation>
    </message>
</context>
<context>
    <name>DiveListSortModel</name>
    <message numerus="yes">
        <location filename="../qt-models/divelistmodel.cpp" line="107"/>
        <source>(%n dive(s))</source>
        <translation><numerusform>(%n dive)</numerusform><numerusform>(%n dives)</numerusform></translation>
    </message>
</context>
<context>
    <name>ShiftTime</name>
    <message numerus="yes">
        <location filename="../desktop-widgets/command_divelist.cpp" line="597"/>
        <source>shift time of %n dives</source>
        <translation><numerusform>shift time of %n dive</numerusform><numerusform>shift time of %n dives</numerusform></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <location filename="../core/qthelper.cpp" line="997"/>
        <source>(%n dive(s))</source>
        <translation><numerusform>(%n dive)</numerusform><numerusform>(%n dives)</numerusform></translation>
    </message>
</context>
</TS>
